@@ -31,8 +31,10 @@ end
 local function get_status(status)
    if status then
       return "ok"
-   else
+   elseif status == false then
       return "not found"
+   else
+      return "failed"
    end
 end
 
@@ -45,7 +47,7 @@ function help.run(...)
    local flags, command = util.parse_flags(...)
 
    if not command then
-      local conf = cfg.which_config()
+      local sys_file, sys_ok, home_file, home_ok = cfg.which_config()
       print_banner()
       print_section("NAME")
       util.printout("\t"..program..[[ - ]]..program_description)
@@ -81,9 +83,9 @@ function help.run(...)
       print_section("CONFIGURATION")
       util.printout("\tLua version: " .. cfg.lua_version)
       util.printout("\tConfiguration files:")
-      util.printout("\t\tSystem: ".. dir.normalize(conf.system.file) .. " (" .. get_status(conf.system.ok) ..")")
-      if conf.user.file then
-         util.printout("\t\tUser  : ".. dir.normalize(conf.user.file) .. " (" .. get_status(conf.user.ok) ..")\n")
+      util.printout("\t\tSystem: ".. dir.normalize(sys_file) .. " (" .. get_status(sys_ok) ..")")
+      if home_file then
+         util.printout("\t\tUser  : ".. dir.normalize(home_file) .. " (" .. get_status(home_ok) ..")\n")
       else
          util.printout("\t\tUser  : disabled in this LuaRocks installation.\n")
       end
